@@ -1,4 +1,4 @@
 ## ----cleanup, include = FALSE--------------------------------------------
 new_files <- setdiff(dir(), original_files)
-file.remove(new_files)
+if (length(new_files)) file.remove(new_files)
 
